import Header from "@/Components/Header";
import React, { useEffect, useState } from "react";
import Footer from "@/Components/Footer";
import InstagramFeeds from "@/Components/InstagramFeeds";
import { router, usePage, Link, Head } from "@inertiajs/react";
import OfferPackages from "@/Components/OfferPackages";
import Button from "@mui/material/Button";
// import AdSense from "react-adsense";

import PhoneInput from "react-phone-input-2";
import "react-phone-input-2/lib/material.css";
import ImageViewModal from "@/Components/ImageViewModal";

import Icon from "@mdi/react";
import {
    mdiCameraOutline,
    mdiCheckOutline,
    mdiStarHalf,
    mdiStar,
    mdiCheckCircle,
    mdiCheckCircleOutline,
    mdiPlus,
    mdiMinus,
} from "@mdi/js";

export default function DestinationDetails() {
    const { destination, auth, flash } = usePage().props;
    useEffect(() => {}, []);
    const user = auth.user;
    const [loading, setLoading] = useState(false);
    const [name, setName] = useState(user ? user.name : null);
    const [phone, setPhone] = useState(user ? user.phone : null);
    const [email, setEmail] = useState(user ? user.email : null);
    const [message, setMessage] = useState(null);
    const [country, setCountry] = useState(null);
    useEffect(() => {
        setMessage(null);
        setEmail(null);
        setPhone(null);
        setName(null);
        setLoading(false);
    }, [flash]);

    const [open, setOpen] = React.useState(false);
    const [imageUrl, setImageUrl] = React.useState(null);

    const showImageModal = (url) => {
        setImageUrl(url);
        setOpen(true);
    };

    return (
        <>
            <Head title={`${destination.name.replace(/\s+/g, "-")}`} />
            <ImageViewModal
                open={open}
                image={imageUrl}
                handleClose={() => {
                    setOpen(false);
                    setImageUrl(null);
                }}
            />
            <div>
                {/*========== HEADER STYLE ONE START ==========*/}
                <Header fixed={false} />
                {/*========== HEADER STYLE ONE END ==========*/}
                {/*========== HERO STYLE ONE START ==========*/}
                {/*========== BREADCRUMB STYLE START ==========*/}
                <div className="paralax-container lg:py-36 py-20 relative overflow-hidden">
                    <div
                        className="jarallax absolute inset-0 z-minus before:content-[''] before:absolute before:inset-0 before:bg-[#030610] before:bg-opacity-50 before:z-minus"
                        data-jarallax=""
                    >
                        <img
                            className="jarallax-img"
                            src={`/${destination.image_cover}`}
                            alt={destination.name}
                        />
                    </div>
                    <img
                        src="/assets/images/illustration/breadcrunb__shape.png"
                        alt="placeholder"
                        className="absolute bottom-0 left-0 z-1 lg:w-[12.5%] w-[20%]"
                    />
                    <img
                        src="/assets/images/illustration/bird-illustration-w.png"
                        alt="placeholder"
                        className="absolute top-[10%] right-[4%] z-1 w-[7.5%]"
                    />
                    <div className="container relative z-2">
                        <nav aria-label="breadcrumb">
                            <ol className="breadcrumb">
                                <li>
                                    <a href="/">Home</a>
                                </li>
                                <li className="active_page">
                                    {destination.name} Destination
                                </li>
                            </ol>
                        </nav>
                        <h2 className="xl:text-[54px] mt-2 lg:text-4xl md:text-2xl text-[30px] text-white leading-[1.3] font-medium max-w-[640px]">
                            {destination.title}
                        </h2>
                    </div>
                </div>
                {/*========== BREADCRUMB STYLE END ==========*/}
                {/*========== DESTINATION DETAILS WRAPPER START ==========*/}
                <div className="relative z-1 bg-gradient-to-t to-[#FFF1EC] from-white lg:pt-[110px] pt-[86px]">
                    <div className="absolute top-1/2 -translate-y-1/2 right-0 max-w-[14%] z-minus lg:inline-block hidden">
                        <img
                            src="/assets/images/illustration/tree-illustration.png"
                            alt="leaf"
                        />
                    </div>
                    <div className="absolute top-[5%] left-[1%] max-w-[9%] z-minus lg:inline-block hidden">
                        <img
                            src="/assets/images/illustration/bird-illustration.png"
                            alt="leaf"
                        />
                    </div>
                    <div className="container">
                        <div className="grid grid-cols-12 gap-base">
                            <div className="lg:col-span-8 col-span-12">
                                <div className="disc__wrapper">
                                    <h3>{destination.title}</h3>
                                    <p>{destination.description1}</p>
                                    <div className="grid grid-cols-2 lg:gap-base gap-5 lg:pt-[10px] lg:pb-9 pb-6">
                                        <div
                                            className="col-span-1 cursor-pointer"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image1
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image1}`}
                                                alt={destination.name}
                                                className="w-full"
                                            />
                                        </div>
                                        <div
                                            className="col-span-1 cursor-pointer"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image2
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image2}`}
                                                alt={destination.name}
                                                className="w-full"
                                            />
                                        </div>
                                    </div>
                                    <p>{destination.description2}</p>
                                    <ul>
                                        {destination.option1 && (
                                            <li>
                                                <Icon
                                                    path={mdiCheckCircleOutline}
                                                    size={0.8}
                                                    className="text-primary-1 text-center mr-2"
                                                />{" "}
                                                {destination.option1}
                                            </li>
                                        )}
                                        {destination.option2 && (
                                            <li>
                                                <Icon
                                                    path={mdiCheckCircleOutline}
                                                    size={0.8}
                                                    className="text-primary-1 text-center mr-2"
                                                />
                                                {destination.option2}
                                            </li>
                                        )}
                                        {destination.option1 && (
                                            <li>
                                                <Icon
                                                    path={mdiCheckCircleOutline}
                                                    size={0.8}
                                                    className="text-primary-1 text-center mr-2"
                                                />
                                                Transportation cost for carrying
                                                new materials/parts
                                            </li>
                                        )}
                                    </ul>
                                    <p>{destination.description_}</p>
                                    {/* <AdSense.Google
                                        client="ca-pub-4460213849771600"
                                        slot="1421134476"
                                        style={{
                                            display: "block",
                                        }}
                                        layoutKey="-eb+4z+3v-fw+n2"
                                        format="fluid"
                                    />{" "} */}
                                    <h3>Good To Know</h3>
                                    <p>{destination.good_to_know_descr}</p>
                                    <ol className="custom_order__list">
                                        <li>
                                            <span className="list__count">
                                                01
                                            </span>
                                            <div className="list__content">
                                                <h5>{destination.option1_}</h5>
                                                <p>
                                                    {destination.option1_desc}
                                                </p>
                                            </div>
                                        </li>
                                    </ol>
                                    <div className="grid grid-cols-8 lg:gap-base gap-4 lg:pt-[10px] lg:pb-9 pb-6">
                                        <div
                                            className="col-span-3 cursor-pointer"
                                            data-fancybox="gallery"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image3
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image3}`}
                                                alt={destination.name}
                                                className="w-full max-h-[260px] object-cover"
                                            />
                                        </div>
                                        <div
                                            className="col-span-5 cursor-pointer"
                                            data-fancybox="gallery"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image4
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image4}`}
                                                alt={destination.name}
                                                className="w-full max-h-[260px] object-cover"
                                            />
                                        </div>
                                        <div
                                            className="col-span-3 cursor-pointer"
                                            data-fancybox="gallery"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image5
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image5}`}
                                                alt={destination.name}
                                                className="w-full max-h-[260px] object-cover"
                                            />
                                        </div>
                                        <div
                                            className="col-span-2 cursor-pointer"
                                            data-fancybox="gallery"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image6
                                                )
                                            }
                                        >
                                            <img
                                                src={`/${destination.image6}`}
                                                alt={destination.name}
                                                className="w-full max-h-[260px] object-cover"
                                            />
                                        </div>
                                        <div
                                            className="col-span-3 cursor-pointer"
                                            onClick={() =>
                                                showImageModal(
                                                    destination.image_cover
                                                )
                                            }
                                            data-fancybox="gallery"
                                        >
                                            <img
                                                src={`/${destination.image_cover}`}
                                                alt={destination.name}
                                                className="w-full max-h-[260px] object-cover"
                                            />
                                        </div>
                                    </div>
                                    <h3>{destination.some_faq}</h3>
                                    <p>{destination.description3}</p>
                                    <div className="lg:pt-10 pt-8">
                                        <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] !mb-base">
                                            {destination.comments &&
                                                destination.comments
                                                    .length}{" "}
                                            Comment’s
                                        </h3>
                                        <ul>
                                            {destination.comments && (
                                                <>
                                                    {destination.comments.map(
                                                        (item, index) => {
                                                            return (
                                                                <li className="bg-[#FFE3EB] bg-opacity-50 lg:px-base px-5 lg:py-base py-5 flex md:flex-row flex-col">
                                                                    <div className="md:mr-5 mb-4 md:mb-0 lg:w-[100px] w-16 rounded-full shrink-0">
                                                                        <img
                                                                            src="/avatar.png"
                                                                            alt="commentor"
                                                                            className="w-full rounded-full"
                                                                        />
                                                                    </div>
                                                                    <div className="grow">
                                                                        <div className="flex justify-between items-center">
                                                                            <h5 className="text-dark-1 lg:text-2md text-md font-medium !mt-0 !mb-0">
                                                                                {
                                                                                    item.name
                                                                                }
                                                                            </h5>
                                                                            <a
                                                                                href="#"
                                                                                className="flex text-primary-1 gap-[6px] text-xs lg:text-md"
                                                                            >
                                                                                Reply
                                                                            </a>
                                                                        </div>
                                                                        <p className="regular-text-v1 lg:mt-3 mt-2 !leading-[1.6] !pb-0">
                                                                            {
                                                                                item.message
                                                                            }
                                                                            .
                                                                        </p>
                                                                    </div>
                                                                </li>
                                                            );
                                                        }
                                                    )}
                                                </>
                                            )}
                                        </ul>
                                    </div>
                                    <form action="#" className="lg:pt-10 pt-8">
                                        <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] !mb-base">
                                            Post A Comments
                                        </h3>
                                        <div className="grid grid-cols-2 gap-base">
                                            {!auth.user && (
                                                <>
                                                    <div className="lg:col-span-1 col-span-2">
                                                        <input
                                                            type="text"
                                                            value={name}
                                                            placeholder="Your Name"
                                                            onChange={(e) =>
                                                                setName(
                                                                    e.target
                                                                        .value
                                                                )
                                                            }
                                                            className="input_style__primary"
                                                        />
                                                    </div>
                                                    <div className="lg:col-span-1 col-span-2">
                                                        <PhoneInput
                                                            country={"uk"}
                                                            enableAreaCodes={
                                                                true
                                                            }
                                                            countryCodeEditable={
                                                                false
                                                            }
                                                            id="phone"
                                                            autoFormat={false}
                                                            name="phone"
                                                            // size="medium"
                                                            value={phone}
                                                            inputStyle={{
                                                                width: "100%",
                                                                height: "11px",
                                                                background:
                                                                    "none",
                                                            }}
                                                            onChange={(e) => {
                                                                setPhone(e);
                                                            }}
                                                            enableSearch={true}
                                                            inputProps={{
                                                                name: "phone",
                                                                // size: "large",
                                                                required: true,
                                                                autoFocus: true,
                                                            }}
                                                            isValid={(
                                                                value,
                                                                country
                                                            ) => {
                                                                if (
                                                                    value.match(
                                                                        /12345/
                                                                    )
                                                                ) {
                                                                    return (
                                                                        "Invalid value: " +
                                                                        value +
                                                                        ", " +
                                                                        country.name
                                                                    );
                                                                } else if (
                                                                    value.match(
                                                                        /12345/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else if (
                                                                    value.match(
                                                                        /1111111/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else if (
                                                                    value.match(
                                                                        /000000/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else {
                                                                    setCountry(
                                                                        country.name
                                                                    );
                                                                    return true;
                                                                }
                                                            }}
                                                        />
                                                    </div>
                                                    <div className="col-span-2">
                                                        <input
                                                            type="email"
                                                            value={email}
                                                            onChange={(e) =>
                                                                setEmail(
                                                                    e.target
                                                                        .value
                                                                )
                                                            }
                                                            placeholder="Your Email"
                                                            className="input_style__primary"
                                                        />
                                                    </div>
                                                </>
                                            )}
                                            <div className="col-span-2">
                                                <textarea
                                                    cols={30}
                                                    value={message}
                                                    rows={6}
                                                    onChange={(e) =>
                                                        setMessage(
                                                            e.target.value
                                                        )
                                                    }
                                                    className="input_style__primary"
                                                    placeholder="Your Message..."
                                                    defaultValue={""}
                                                />
                                            </div>
                                            <div className="col-span-2">
                                                {loading ? (
                                                    <Button
                                                        variant="contained"
                                                        disabled={true}
                                                    >
                                                        Posting...
                                                    </Button>
                                                ) : (
                                                    <button
                                                        type="submit"
                                                        onClick={(e) => {
                                                            e.preventDefault();
                                                            setLoading(true);
                                                            // console.log({
                                                            //     package_id:
                                                            //         destination.id,
                                                            //     name,
                                                            //     email,
                                                            //     phone,
                                                            //     message,
                                                            // });
                                                            router.post(
                                                                "/post-comment",
                                                                {
                                                                    destination_id:
                                                                        destination.id,
                                                                    name,
                                                                    email,
                                                                    phone,
                                                                    message,
                                                                }
                                                            );
                                                        }}
                                                        className="btn_primary__v1"
                                                        // disabled={true}
                                                    >
                                                        Post
                                                        {/* <i className="bi bi-chevron-right" /> */}
                                                    </button>
                                                )}
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                            <div class="lg:col-span-4 col-span-12">
                                <OfferPackages />
                            </div>
                        </div>
                    </div>
                </div>
                {/*========== DESTINATION DETAILS WRAPPER END ==========*/}
                {/* <AdSense.Google
                    client="ca-pub-4460213849771600"
                    slot="1421134476"
                    style={{
                        display: "block",
                    }}
                    layoutKey="-eb+4z+3v-fw+n2"
                    // responsive="true"
                    format="fluid"
                />{" "} */}
                {/*========== INSTAGRAM FEED STYLE START ==========*/}
                {/* <InstagramFeeds /> */}
                {/*========== INSTAGRAM FEED STYLE END ==========*/}
                {/*========== FOOTER STYLE START ==========*/}
                <Footer />
                {/*========== FOOTER STYLE END ==========*/}
            </div>
        </>
    );
}
